package com.hzya.frame.voucher.ae.comf.bd.controller;

import cn.hutool.core.lang.Assert;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.hzya.frame.voucher.ae.comf.bd.dao.IAeConfBdAccsubjDao;
import com.hzya.frame.voucher.ae.comf.bd.dao.IAeConfBdBdinfoDao;
import com.hzya.frame.voucher.ae.comf.bd.dao.IAeConfBdOrgBookVODao;
import com.hzya.frame.voucher.ae.comf.bd.dao.IU8CQueryVODAO;
import com.hzya.frame.voucher.ae.comf.bd.entity.*;
import com.hzya.frame.voucher.ae.comf.bd.utils.AccsubjTreeBuilder;
import com.hzya.frame.voucher.constant.ProfilesActiveConstant;
import com.hzya.frame.web.action.DefaultController;
import com.hzya.frame.web.entity.BaseEntity;
import com.hzya.frame.web.entity.JsonResultEntity;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * Created by zydd on 2025-06-04 15:04
 */
@RestController
@RequestMapping("/ae/conf/bd")
public class BdController extends DefaultController {

    @Autowired
    private IAeConfBdOrgBookVODao aeConfBdOrgBookVODao;
    @Autowired
    private IAeConfBdBdinfoDao aeConfBdBdinfoDao;
    @Autowired
    private IAeConfBdAccsubjDao aeConfBdAccsubjDao;
    @Autowired
    private IU8CQueryVODAO u8CQueryVODAO;

    /**
     * 查询所有公司账簿信息
     */
    @RequestMapping(value = "/queryOrgBookVO", method = RequestMethod.POST)
    public JsonResultEntity queryOrgBookVO(@RequestBody OrgBookVO vo) {
        try {
            List<OrgBookVO> all = aeConfBdOrgBookVODao.queryOrgBookVO(vo);
            return getSuccessMessageEntity("请求成功", all);
        } catch (Exception e) {
            e.printStackTrace();
            return getFailureMessageEntity("请求失败", e.getMessage());
        }
    }

    /**
     * 查询基础数据资源表
     */
    @RequestMapping(value = "/queryBdinfoList", method = RequestMethod.POST)
    public JsonResultEntity queryBdinfoList(@RequestBody AeConfBdBdinfoEntity entity) {
        try {
            List<AeConfBdBdinfoEntity> all = aeConfBdBdinfoDao.queryByLike(entity);
            return getSuccessMessageEntity("请求成功", all);
        } catch (Exception e) {
            e.printStackTrace();
            return getFailureMessageEntity("请求失败", e.getMessage());
        }
    }

    /**
     * 查询科目表根据账簿id
     */
    @RequestMapping(value = "/queryAccSubjByOrgBookId", method = RequestMethod.POST)
    public JsonResultEntity queryAccSubjByOrgBookId(@RequestBody AeConfBdAccsubjEntity entity) {
        try {
            Assert.notNull(entity.getPkGlorgbook(), "查询科目表时，账簿id不允许为空");
            List<AeConfBdAccsubjEntity> all = aeConfBdAccsubjDao.query(entity);
            List<AccsubjTreeNode> tree = AccsubjTreeBuilder.buildTree(all);
            return getSuccessMessageEntity("请求成功", tree);
        } catch (Exception e) {
            e.printStackTrace();
            return getFailureMessageEntity("请求失败", e.getMessage());
        }
    }

    /**
     * 查询基础数据数据表
     */
    @RequestMapping(value = "/queryDataByMap", method = RequestMethod.POST)
    public JsonResultEntity queryDataByMap(@RequestBody HashMap<String, String> map) {
        try {
            if (map.get("tablename") == null || "".equals(map.get("tablename"))) {
                return getSuccessMessageEntity("请求成功", null);
            }
            //查询u8c数据库
            U8CQueryVO u8CQueryVO = new U8CQueryVO();
            u8CQueryVO.setDataSourceCode(ProfilesActiveConstant.LETS_PROD_DATE_SOURCE);
            u8CQueryVO.setTablename(map.get("tablename"));
            List<Map<String, Object>> objectList = u8CQueryVODAO.queryU8CBD(u8CQueryVO);

            return getSuccessMessageEntity("请求成功", objectList);
        } catch (Exception e) {
            e.printStackTrace();
            return getFailureMessageEntity("请求失败", e.getMessage());
        }
    }

    /**
     * 查询基础数据数据表
     */
    @RequestMapping(value = "/queryDataPagedByMap", method = RequestMethod.POST)
    public JsonResultEntity queryDataPagedByMap(@RequestBody U8CQueryVO entity) {
        try {
            if (entity.getTablename() == null || "".equals(entity.getTablename())) {
                return getSuccessMessageEntity("请求成功", null);
            }
            PageHelper.startPage(entity.getPageNum(), entity.getPageSize());
            //查询u8c数据库
            U8CQueryVO u8CQueryVO = new U8CQueryVO();
            u8CQueryVO.setDataSourceCode(ProfilesActiveConstant.LETS_PROD_DATE_SOURCE);
            u8CQueryVO.setTablename(entity.getTablename());
            List<Map<String, Object>> objectList = u8CQueryVODAO.queryU8CBD(u8CQueryVO);
            PageInfo pageInfo = new PageInfo(objectList);

            return getSuccessMessageEntity("请求成功", pageInfo);
        } catch (Exception e) {
            e.printStackTrace();
            return getFailureMessageEntity("请求失败", e.getMessage());
        }
    }
}
