package com.hzya.frame.voucher.ae.comf.module.service.impl;

import cn.hutool.core.lang.Assert;
import cn.hutool.json.JSONUtil;
import com.github.pagehelper.PageInfo;
import com.hzya.frame.mdm.mdmModule.dao.IMdmModuleDao;
import com.hzya.frame.mdm.mdmModule.entity.MdmModuleEntity;
import com.hzya.frame.voucher.ae.comf.factor.dao.IAeConfInfluenceFactorCorrelationDao;
import com.hzya.frame.voucher.ae.comf.factor.dao.IAeConfInfluenceFactorDao;
import com.hzya.frame.voucher.ae.comf.factor.entity.AeConfInfluenceFactorCorrelationEntity;
import com.hzya.frame.voucher.ae.comf.factor.entity.AeConfInfluenceFactorEntity;
import com.hzya.frame.voucher.ae.comf.module.dao.IAeConfBusinessModuleDao;
import com.hzya.frame.voucher.ae.comf.module.entity.AeConfBusinessModuleEntity;
import com.hzya.frame.voucher.ae.comf.module.entity.AeConfBusinessModuleMdmEntity;
import com.hzya.frame.voucher.ae.comf.module.dao.IAeConfBusinessModuleMdmDao;
import com.hzya.frame.voucher.ae.comf.module.service.IAeConfBusinessModuleMdmService;
import org.springframework.stereotype.Service;
import org.springframework.beans.factory.annotation.Autowired;
import com.hzya.frame.basedao.service.impl.BaseService;

import java.util.*;
import java.util.stream.Collectors;

/**
 * 会计事项(accounting_event)-配置-业务模块-单据类型-关联(AeConfBusinessModuleBillType)表服务实现类
 *
 * @author zydd
 * @since 2025-05-23 16:31:42
 */
@Service
public class AeConfBusinessModuleMdmServiceImpl extends BaseService<AeConfBusinessModuleMdmEntity, String> implements IAeConfBusinessModuleMdmService {

    private IAeConfBusinessModuleMdmDao aeConfBusinessModuleMdmDao;

    @Autowired
    public void setaeConfBusinessModuleMdmDao(IAeConfBusinessModuleMdmDao dao) {
        this.aeConfBusinessModuleMdmDao = dao;
        this.dao = dao;
    }

    @Autowired
    private IMdmModuleDao mdmModuleDao;
    @Autowired
    private IAeConfBusinessModuleDao aeConfBusinessModuleDao;
    @Autowired
    private IAeConfInfluenceFactorCorrelationDao aeConfInfluenceFactorCorrelationDao;
    @Autowired
    private IAeConfInfluenceFactorDao aeConfInfluenceFactorDao;


    @Override
    public List<AeConfBusinessModuleMdmEntity> queryAll(AeConfBusinessModuleMdmEntity entity) {
        List<AeConfBusinessModuleMdmEntity> all = aeConfBusinessModuleMdmDao.query(entity);
        return all;
    }

    /**
     * 查询全部业务业务模块，里面包含主数据
     */
    @Override
    public List<AeConfBusinessModuleMdmEntity> queryModuleIncludeMdmList(AeConfBusinessModuleMdmEntity entity) {
        List<AeConfBusinessModuleMdmEntity> all = new ArrayList<>();
        List<AeConfBusinessModuleMdmEntity> aeConfBusinessModuleMdmEntityList = aeConfBusinessModuleMdmDao.query(entity);
        Map<String, List<AeConfBusinessModuleMdmEntity>> collect =
                aeConfBusinessModuleMdmEntityList.stream().collect(Collectors.groupingBy(index -> index.getAeConfModuleId() + "###" + index.getAeConfModuleName()));
        Set<Map.Entry<String, List<AeConfBusinessModuleMdmEntity>>> entries = collect.entrySet();
        for (Map.Entry<String, List<AeConfBusinessModuleMdmEntity>> entry : entries) {
            String key = entry.getKey();//moduleId###moduleName
            List<AeConfBusinessModuleMdmEntity> value = entry.getValue();
            List<MdmModuleEntity> mdmList = new ArrayList<>();
            for (AeConfBusinessModuleMdmEntity aeConfBusinessModuleMdmEntity : value) {
                MdmModuleEntity mdmModuleEntity = new MdmModuleEntity();
                mdmModuleEntity.setId(aeConfBusinessModuleMdmEntity.getMdmId());
                mdmModuleEntity.setMdmCode(Long.valueOf(aeConfBusinessModuleMdmEntity.getMdmCode()));
                mdmModuleEntity.setMdmName(aeConfBusinessModuleMdmEntity.getMdmName());
                mdmList.add(mdmModuleEntity);
            }

            AeConfBusinessModuleMdmEntity aeConfBusinessModuleMdmEntity = new AeConfBusinessModuleMdmEntity();
            String[] split = key.split("###");
            aeConfBusinessModuleMdmEntity.setAeConfModuleId(Long.valueOf(split[0]));
            aeConfBusinessModuleMdmEntity.setAeConfModuleName(split[1]);
            aeConfBusinessModuleMdmEntity.setMdmModuleEntity(mdmList);
            all.add(aeConfBusinessModuleMdmEntity);
        }
        return all;
    }

    /**
     * 根据模块id查询主数据
     */
    @Override
    public List<AeConfBusinessModuleMdmEntity> queryMdmsByModuleId(AeConfBusinessModuleMdmEntity entity) {
        Assert.notNull(entity.getAeConfModuleId(), "查询主数据列表时，业务模块id不能为空");
        List<AeConfBusinessModuleMdmEntity> all = aeConfBusinessModuleMdmDao.query(entity);
        return all;
    }

    /**
     * 保存业务模块-主数据关联关系，一对一的关系，需要校验
     */
    @Override
    public List<AeConfBusinessModuleMdmEntity> saveList(List<AeConfBusinessModuleMdmEntity> list) {
        if (list.size() == 0) {
            Assert.state(false, "业务模块-主数据保存时，数据不能为空，请检查！");
        }
        for (AeConfBusinessModuleMdmEntity moduleMdmEntity : list) {
            Assert.notNull(moduleMdmEntity.getAeConfModuleId(), "业务模块-主数据保存时，业务模块id不能为空，请检查！检验数据为：{}", JSONUtil.toJsonStr(moduleMdmEntity));
            Assert.notNull(moduleMdmEntity.getAeConfModuleName(), "业务模块-主数据保存时，业务模块name不能为空，请检查！检验数据为：{}", JSONUtil.toJsonStr(moduleMdmEntity));
            Assert.notNull(moduleMdmEntity.getMdmId(), "业务模块-主数据保存时，主数据id不能为空，请检查！检验数据为：{}", JSONUtil.toJsonStr(moduleMdmEntity));
            Assert.notNull(moduleMdmEntity.getMdmCode(), "业务模块-主数据保存时，主数据code不能为空，请检查！检验数据为：{}", JSONUtil.toJsonStr(moduleMdmEntity));
            Assert.notNull(moduleMdmEntity.getMdmName(), "业务模块-主数据保存时，主数据name不能为空，请检查！检验数据为：{}", JSONUtil.toJsonStr(moduleMdmEntity));
        }

        //校验是否存在重复
        for (AeConfBusinessModuleMdmEntity aeConfBusinessModuleMdmEntity : list) {
            AeConfBusinessModuleMdmEntity ae1 = new AeConfBusinessModuleMdmEntity();
            ae1.setAeConfModuleId(aeConfBusinessModuleMdmEntity.getAeConfModuleId());
            ae1.setMdmId(aeConfBusinessModuleMdmEntity.getMdmId());
            List<AeConfBusinessModuleMdmEntity> query1 = aeConfBusinessModuleMdmDao.query(ae1);
            if (query1.size() > 0) {
                Assert.state(false, "该主数据：{}，已和模块：{}，绑定，请检查。", aeConfBusinessModuleMdmEntity.getMdmName(), aeConfBusinessModuleMdmEntity.getAeConfModuleName());
            }
        }
        List<AeConfBusinessModuleMdmEntity> saveList = new ArrayList<>();
        for (AeConfBusinessModuleMdmEntity aeConfBusinessModuleMdmEntity : list) {
            AeConfBusinessModuleMdmEntity save = aeConfBusinessModuleMdmDao.save(aeConfBusinessModuleMdmEntity);
            saveList.add(save);
        }
        return saveList;
    }

    /**
     * 更新时需要检查，有没有配置影响因素，有则不允许更新
     */
    @Override
    public List<AeConfBusinessModuleMdmEntity> updateList(List<AeConfBusinessModuleMdmEntity> list) {
        if (list.size() == 0) {
            Assert.state(false, "业务模块-主数据更新时，数据不能为空，请检查！");
        }
        for (AeConfBusinessModuleMdmEntity moduleMdmEntity : list) {
            Assert.notNull(moduleMdmEntity.getId(), "业务模块-主数据保存时，业务模块-主数据id不能为空，请检查！检验数据为：{}", JSONUtil.toJsonStr(moduleMdmEntity));
            Assert.notNull(moduleMdmEntity.getAeConfModuleId(), "业务模块-主数据保存时，业务模块id不能为空，请检查！检验数据为：{}", JSONUtil.toJsonStr(moduleMdmEntity));
            Assert.notNull(moduleMdmEntity.getAeConfModuleName(), "业务模块-主数据保存时，业务模块name不能为空，请检查！检验数据为：{}", JSONUtil.toJsonStr(moduleMdmEntity));
            Assert.notNull(moduleMdmEntity.getMdmId(), "业务模块-主数据保存时，主数据id不能为空，请检查！检验数据为：{}", JSONUtil.toJsonStr(moduleMdmEntity));
            Assert.notNull(moduleMdmEntity.getMdmCode(), "业务模块-主数据保存时，主数据code不能为空，请检查！检验数据为：{}", JSONUtil.toJsonStr(moduleMdmEntity));
            Assert.notNull(moduleMdmEntity.getMdmName(), "业务模块-主数据保存时，主数据name不能为空，请检查！检验数据为：{}", JSONUtil.toJsonStr(moduleMdmEntity));
        }
        //查询影响因素,再根据影响因素查询业务模块
        for (AeConfBusinessModuleMdmEntity moduleMdmEntity : list) {
            AeConfInfluenceFactorCorrelationEntity factorCorrelation = new AeConfInfluenceFactorCorrelationEntity();
            factorCorrelation.setMdmId(moduleMdmEntity.getMdmId());
            List<AeConfInfluenceFactorCorrelationEntity> query = aeConfInfluenceFactorCorrelationDao.query(factorCorrelation);
            //查询模块id
//            List<Long> factorIds = query.stream()
//                    .map(AeConfInfluenceFactorCorrelationEntity::getFactorId)
//                    .collect(Collectors.toList());
            List<Long> factorIds = Optional.ofNullable(query).orElse(Collections.emptyList()).stream()
                    .map(AeConfInfluenceFactorCorrelationEntity::getFactorId)
                    .collect(Collectors.toList());
            for (Long factorId : factorIds) {
                AeConfInfluenceFactorEntity aeConfInfluenceFactorEntity = new AeConfInfluenceFactorEntity();
                aeConfInfluenceFactorEntity.setId(String.valueOf(factorId));
                List<AeConfInfluenceFactorEntity> query1 = aeConfInfluenceFactorDao.query(aeConfInfluenceFactorEntity);
                AeConfInfluenceFactorEntity aeConfInfluenceFactorEntity1 = query1.get(0);
                if(!aeConfInfluenceFactorEntity1.getAeConfModuleId().equals(moduleMdmEntity.getAeConfModuleId())){
                    Assert.state(false,"该主数据已关联影响因素，请删除影响因素关联后进行修改");
                }
            }
        }

        List<AeConfBusinessModuleMdmEntity> updateList = new ArrayList<>();
        for (AeConfBusinessModuleMdmEntity aeConfBusinessModuleMdmEntity : list) {
            AeConfBusinessModuleMdmEntity update = aeConfBusinessModuleMdmDao.update(aeConfBusinessModuleMdmEntity);
            updateList.add(update);
        }
        return updateList;
    }

    @Override
    public Map<String, Integer> deleteList(List<AeConfBusinessModuleMdmEntity> list) {
        if (list.size() == 0) {
            Assert.state(false, "业务模块-主数据删除时，数据不能为空，请检查！");
        }
        for (AeConfBusinessModuleMdmEntity moduleMdmEntity : list) {
            Assert.notNull(moduleMdmEntity.getId(), "业务模块-主数据删除时，业务模块-主数据id不能为空，请检查！检验数据为：{}", JSONUtil.toJsonStr(moduleMdmEntity));
        }

        //查询影响因素,再根据影响因素查询业务模块
        for (AeConfBusinessModuleMdmEntity moduleMdmEntity : list) {
            AeConfInfluenceFactorCorrelationEntity factorCorrelation = new AeConfInfluenceFactorCorrelationEntity();
            factorCorrelation.setMdmId(moduleMdmEntity.getMdmId());
            List<AeConfInfluenceFactorCorrelationEntity> query = aeConfInfluenceFactorCorrelationDao.query(factorCorrelation);
            //查询模块id
//            List<Long> factorIds = query.stream()
//                    .map(AeConfInfluenceFactorCorrelationEntity::getFactorId)
//                    .collect(Collectors.toList());
            List<Long> factorIds = Optional.ofNullable(query).orElse(Collections.emptyList()).stream()
                    .map(AeConfInfluenceFactorCorrelationEntity::getFactorId)
                    .collect(Collectors.toList());
            for (Long factorId : factorIds) {
                AeConfInfluenceFactorEntity aeConfInfluenceFactorEntity = new AeConfInfluenceFactorEntity();
                aeConfInfluenceFactorEntity.setId(String.valueOf(factorId));
                List<AeConfInfluenceFactorEntity> query1 = aeConfInfluenceFactorDao.query(aeConfInfluenceFactorEntity);
                AeConfInfluenceFactorEntity aeConfInfluenceFactorEntity1 = query1.get(0);
                if(!aeConfInfluenceFactorEntity1.getAeConfModuleId().equals(moduleMdmEntity.getAeConfModuleId())){
                    Assert.state(false,"该主数据已关联影响因素，请删除影响因素关联后进行删除");
                }
            }
        }

        Map<String, Integer> deleteMap = new HashMap<>();
        for (AeConfBusinessModuleMdmEntity aeConfBusinessModuleMdmEntity : list) {
            int i = aeConfBusinessModuleMdmDao.logicRemove(aeConfBusinessModuleMdmEntity);
            deleteMap.put(aeConfBusinessModuleMdmEntity.getId(), i);
        }
        return deleteMap;
    }


}
