package com.hzya.frame.voucher.ae.comf.subject.service.impl;

import cn.hutool.core.lang.Assert;
import com.hzya.frame.voucher.ae.comf.subject.dao.IAeConfSubjectContrastDao;
import com.hzya.frame.voucher.ae.comf.subject.entity.AeConfSubjectContrastBEntity;
import com.hzya.frame.voucher.ae.comf.subject.dao.IAeConfSubjectContrastBDao;
import com.hzya.frame.voucher.ae.comf.subject.entity.AeConfSubjectContrastEntity;
import com.hzya.frame.voucher.ae.comf.subject.service.IAeConfSubjectContrastBService;
import org.springframework.stereotype.Service;
import org.springframework.beans.factory.annotation.Autowired;

import javax.annotation.Resource;

import com.hzya.frame.basedao.service.impl.BaseService;

import java.util.ArrayList;
import java.util.List;

/**
 * 会计事项(accounting_event)-配置-科目对照_子表(AeConfSubjectContrastB)表服务实现类
 *
 * @author zydd
 * @since 2025-06-05 15:13:29
 */
@Service
public class AeConfSubjectContrastBServiceImpl extends BaseService<AeConfSubjectContrastBEntity, String> implements IAeConfSubjectContrastBService {

    private IAeConfSubjectContrastBDao aeConfSubjectContrastBDao;

    @Autowired
    public void setAeConfSubjectContrastBDao(IAeConfSubjectContrastBDao dao) {
        this.aeConfSubjectContrastBDao = dao;
        this.dao = dao;
    }

    @Autowired
    private IAeConfSubjectContrastDao aeConfSubjectContrastDao;

    /**
     * 根据contrastId查询所有子表
     */
    @Override
    public List<AeConfSubjectContrastBEntity> queryAllByContrastId(AeConfSubjectContrastBEntity entity) {
        Assert.notNull(entity.getContrastId(), "根据科目对照子表查询，所属所有子表时，contrastId不能为空");
        AeConfSubjectContrastBEntity aeConfSubjectContrastBEntity = new AeConfSubjectContrastBEntity();
        aeConfSubjectContrastBEntity.setContrastId(entity.getContrastId());
        List<AeConfSubjectContrastBEntity> query = aeConfSubjectContrastBDao.query(aeConfSubjectContrastBEntity);
        return query;
    }

    /**
     * 依次保存批量新增
     */
    @Override
    public List<AeConfSubjectContrastBEntity> saveListEntity(List<AeConfSubjectContrastBEntity> list) {
        if (list == null || list.size() == 0) {
            Assert.state(false, "批量新增科目对照子表时，子表不能为空。");
        }
        for (AeConfSubjectContrastBEntity aeConfSubjectContrastBEntity : list) {
            Assert.notNull(aeConfSubjectContrastBEntity.getContrastId(), "新增科目对照子表时，contrastId不能为空");
            Assert.notNull(aeConfSubjectContrastBEntity.getPkCorp(), "新增科目对照子表时，公司主键不能为空");
        }
        //检查主表是否存在
        AeConfSubjectContrastEntity aeConfSubjectContrastEntity = new AeConfSubjectContrastEntity();
        aeConfSubjectContrastEntity.setId(String.valueOf(list.get(0).getContrastId()));
        List<AeConfSubjectContrastEntity> query = aeConfSubjectContrastDao.query(aeConfSubjectContrastEntity);
        if (query == null || query.size() == 0) {
            Assert.state(false, "新增科目对照子表时，主表不存在。");
        }
        List<AeConfSubjectContrastBEntity> all = new ArrayList<>();
        for (AeConfSubjectContrastBEntity aeConfSubjectContrastBEntity : list) {
            AeConfSubjectContrastBEntity save = aeConfSubjectContrastBDao.save(aeConfSubjectContrastBEntity);
            all.add(save);
        }
        return all;
    }

    @Override
    public List<AeConfSubjectContrastBEntity> updateList(List<AeConfSubjectContrastBEntity> list) {
        if (list == null || list.size() == 0) {
            Assert.state(false, "批量修改科目对照子表时，子表不能为空。");
        }
        for (AeConfSubjectContrastBEntity aeConfSubjectContrastBEntity : list) {
            Assert.notNull(aeConfSubjectContrastBEntity.getId(), "修改科目对照子表时，子表id不能为空");
            Assert.notNull(aeConfSubjectContrastBEntity.getContrastId(), "修改科目对照子表时，主表不能为空");
            Assert.notNull(aeConfSubjectContrastBEntity.getPkCorp(), "修改科目对照子表时，子表公司主键不能为空");
        }
        //检查主表是否存在
        AeConfSubjectContrastEntity aeConfSubjectContrastEntity = new AeConfSubjectContrastEntity();
        aeConfSubjectContrastEntity.setId(String.valueOf(list.get(0).getContrastId()));
        List<AeConfSubjectContrastEntity> query = aeConfSubjectContrastDao.query(aeConfSubjectContrastEntity);
        if (query == null || query.size() == 0) {
            Assert.state(false, "修改科目对照子表时，主表不存在。");
        }
        for (AeConfSubjectContrastBEntity aeConfSubjectContrastBEntity : list) {
            aeConfSubjectContrastBDao.update(aeConfSubjectContrastBEntity);
        }
        return list;
    }

    @Override
    public void deleteList(AeConfSubjectContrastBEntity entity) {
            Assert.notNull(entity.getId(), "删除科目对照子表时，子表id不能为空");
            aeConfSubjectContrastBDao.logicRemove(entity);
        }


}
