package com.hzya.frame.voucher.ae.comf.subject.service.impl;

import cn.hutool.core.lang.Assert;
import com.hzya.frame.voucher.ae.comf.factor.service.IAeConfInfluenceFactorService;
import com.hzya.frame.voucher.ae.comf.subject.dao.IAeConfSubjectContrastBDao;
import com.hzya.frame.voucher.ae.comf.subject.entity.AeConfSubjectContrastBEntity;
import com.hzya.frame.voucher.ae.comf.subject.entity.AeConfSubjectContrastEntity;
import com.hzya.frame.voucher.ae.comf.subject.dao.IAeConfSubjectContrastDao;
import com.hzya.frame.voucher.ae.comf.subject.service.IAeConfSubjectContrastService;
import org.springframework.stereotype.Service;
import org.springframework.beans.factory.annotation.Autowired;

import com.hzya.frame.basedao.service.impl.BaseService;

import java.lang.reflect.Field;
import java.util.List;

/**
 * 会计事项(accounting_event)-配置-科目对照(AeConfSubjectContrast)表服务实现类
 *
 * @author zydd
 * @since 2025-05-30 15:04:47
 */
@Service
public class AeConfSubjectContrastServiceImpl extends BaseService<AeConfSubjectContrastEntity, String> implements IAeConfSubjectContrastService {

    private IAeConfSubjectContrastDao aeConfSubjectContrastDao;

    @Autowired
    public void setAeConfSubjectContrastDao(IAeConfSubjectContrastDao dao) {
        this.aeConfSubjectContrastDao = dao;
        this.dao = dao;
    }

    @Autowired
    private IAeConfSubjectContrastBDao aeConfSubjectContrastBDao;
    @Autowired
    private IAeConfInfluenceFactorService iAeConfInfluenceFactorService;

    @Override
    public List<AeConfSubjectContrastEntity> queryAll(AeConfSubjectContrastEntity entity) {
        Assert.notNull(entity.getPkCorp(), "查询全部对照表时，公司id不能为空！");
        List<AeConfSubjectContrastEntity> aeConfSubjectContrastEntityList = aeConfSubjectContrastDao.query(entity);
        //查询子表
        for (AeConfSubjectContrastEntity confSubjectContrastEntity : aeConfSubjectContrastEntityList) {
            AeConfSubjectContrastBEntity aeConfSubjectContrastBEntity = new AeConfSubjectContrastBEntity();
            aeConfSubjectContrastBEntity.setContrastId(Long.valueOf(confSubjectContrastEntity.getId()));
            List<AeConfSubjectContrastBEntity> aeConfSubjectContrastBEntityList = aeConfSubjectContrastBDao.query(aeConfSubjectContrastBEntity);
            confSubjectContrastEntity.setContrastBEntityList(aeConfSubjectContrastBEntityList);
        }
        return aeConfSubjectContrastEntityList;
    }

    @Override
    public AeConfSubjectContrastEntity queryById(AeConfSubjectContrastEntity entity) {
        Assert.notNull(entity.getPkCorp(), "根据id查询科目对照时，公司id不能为空！");
        Assert.notNull(entity.getId(), "根据id查询科目对照时，科目对照表id不能为空");
        List<AeConfSubjectContrastEntity> aeConfSubjectContrastEntityList = aeConfSubjectContrastDao.query(entity);
        if (aeConfSubjectContrastEntityList.size() == 0) {
            Assert.state(false, "根据科目对照表id：{}，未查询到科目对照！", entity.getId());
        }
        if (aeConfSubjectContrastEntityList.size() > 1) {
            Assert.state(false, "根据科目对照表id：{}，查询到科目对照不唯一！", entity.getId());
        }
        AeConfSubjectContrastEntity contrastEntity = aeConfSubjectContrastEntityList.get(0);
        //查询子表
        AeConfSubjectContrastBEntity aeConfSubjectContrastBEntity = new AeConfSubjectContrastBEntity();
        aeConfSubjectContrastBEntity.setContrastId(Long.valueOf(contrastEntity.getId()));
        List<AeConfSubjectContrastBEntity> aeConfSubjectContrastBEntityList = aeConfSubjectContrastBDao.query(aeConfSubjectContrastBEntity);
        contrastEntity.setContrastBEntityList(aeConfSubjectContrastBEntityList);

        return contrastEntity;
    }

    /**
     * 新增科目对照表。现保存主表，再将来源档案分割为子表进行存储
     */
    @Override
    public AeConfSubjectContrastEntity saveEntity(AeConfSubjectContrastEntity entity) throws NoSuchFieldException, IllegalAccessException {
        //校验主表
        Assert.notNull(entity.getPkCorp(), "科目对照表新增时，公司id不能为空！");
        Assert.notNull(entity.getCode(), "科目对照表新增时，code不能为空！");
        Assert.notNull(entity.getName(), "科目对照表新增时，name不能为空！");
        Assert.notNull(entity.getAccountBookTypeId(), "科目对照表新增时，账簿类型id不能为空！");
        Assert.notNull(entity.getAccountBookTypeCode(), "科目对照表新增时，账簿类型code不能为空！");
        Assert.notNull(entity.getAccountBookTypeName(), "科目对照表新增时，账簿类型name不能为空！");
        Assert.notNull(entity.getSourceIds(), "科目对照表新增时，来源档案ids不能为空！");
        Assert.notNull(entity.getSourceNames(), "科目对照表新增时，来源档案names不能为空！");


        List<AeConfSubjectContrastBEntity> contrastBList = entity.getContrastBEntityList();
//        Assert.notNull(contrastBList, "科目对照表新增时，来源档案不能为空！");
//        if (contrastBList == null || contrastBList.size() == 0) {
//            Assert.state(false, "科目对照表新增时，来源档案VOS不能为空！");
//        }
//        if (contrastBList.size() > 9) {
//            Assert.state(false, "科目对照表新增时，来源档案VOS最多为9个！");
//        }

//        //校验子表
//        for (int i = 1; i <= split.length; i++) {
//            String fieldName = "factortable" + i;
//            Field field = AeConfSubjectContrastBEntity.class.getDeclaredField(fieldName);
//            field.setAccessible(true);
//            String value = (String) field.get(entity);
//
//            if (value == null || value.trim().isEmpty()) {
//                Assert.state(false, "");
//            }
//        }


        //保存主表
        AeConfSubjectContrastEntity saveH = aeConfSubjectContrastDao.save(entity);
        String Hid = saveH.getId();
        String HpkCorp = saveH.getPkCorp();

        if (contrastBList == null || contrastBList.size() == 0) {
            return saveH;
        }

        //保存子表
        for (AeConfSubjectContrastBEntity aeConfSubjectContrastBEntity : contrastBList) {
            aeConfSubjectContrastBEntity.setContrastId(Long.valueOf(Hid));
            aeConfSubjectContrastBEntity.setPkCorp(HpkCorp);
            aeConfSubjectContrastBDao.save(aeConfSubjectContrastBEntity);
        }
        return saveH;
    }


    /**
     * 将原有的主子表全部删除，再重新新增
     */
    @Override
    public AeConfSubjectContrastEntity updateEntity(AeConfSubjectContrastEntity entity) throws Exception {
        Assert.notNull(entity.getId(), "科目对照表修改时，科目对照表id不能为空！");
        AeConfSubjectContrastEntity aeConfSubjectContrastEntity = new AeConfSubjectContrastEntity();
        aeConfSubjectContrastEntity.setId(entity.getId());
        List<AeConfSubjectContrastEntity> query = aeConfSubjectContrastDao.query(aeConfSubjectContrastEntity);
        if (query == null || query.size() == 0) {
            Assert.state(false, "科目对照表修改时，科目对照表id：{}，未查询到科目对照！", entity.getId());
        }
        deleteEntity(entity);
        saveEntity(entity);
        return null;
    }

    /**
     * 将原有的主子表全部删除
     */
    @Override
    public AeConfSubjectContrastEntity deleteEntity(AeConfSubjectContrastEntity entity) throws Exception {
        Assert.notNull(entity.getId(), "科目对照表删除时，科目对照表id不能为空！");
        aeConfSubjectContrastDao.logicRemove(entity);
        //查询子表
        AeConfSubjectContrastBEntity ContrastBEntity = new AeConfSubjectContrastBEntity();
        ContrastBEntity.setContrastId(Long.valueOf(entity.getId()));
        List<AeConfSubjectContrastBEntity> query = aeConfSubjectContrastBDao.query(ContrastBEntity);
        for (AeConfSubjectContrastBEntity aeConfSubjectContrastBEntity : query) {
            aeConfSubjectContrastBDao.logicRemove(aeConfSubjectContrastBEntity);
        }
        return null;
    }

    /**
     * 1、根据入参影响因素ids，分别查询影响因素设置的对应基础档案类型
     * 2、再按顺序拼接写类型的ids，再去科目对照表中查询这个ids对应的对照表
     * 3、返回对照表对象
     */
    @Override
    public AeConfSubjectContrastEntity queryByInfluenceIds(AeConfSubjectContrastEntity entity) {
        Assert.notNull(entity.getSourceIds(), "根据影响因素ids查询时对照表时，来源档案ids不能为空！");
        String sourceIds = entity.getSourceIds();
        String[] sourceIdSplit = sourceIds.split(",");


        iAeConfInfluenceFactorService.query(null);



        return null;
    }
}
